@@ -6,7 +6,18 @@ sub register {
     my ( $self, $app, $conf ) = @_;
     push @{ $app->renderer->classes }, __PACKAGE__;
     $app->add_view( "activity", "test" );
-    $app->add_view( "activity", "test2" );
+    $app->add_view(
+        "activity",
+        sub {
+            return shift->render_to_string(
+                template => "test2",
+                format   => "html"
+            );
+        }
+    );
+    use Data::Dumper;
+
+    print STDERR Dumper($self);
 
     $app->helper(
         test => sub {
@@ -16,14 +27,6 @@ sub register {
             );
         }
     );
-    $app->helper(
-        test2 => sub {
-            return shift->render_to_string(
-                template => "test2",
-                format   => "html"
-            );
-        }
-    );
 
 }
 
@@ -32,4 +35,4 @@ __DATA__
 @@ test.html.ep
 double it!
 @@ test2.html.ep
-42
\ No newline at end of file
+42
